Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(815)

Unified Diff: webrtc/pc/dtmfsender.cc

Issue 2699503002: Change minimum DTMF event duration to be 40 milliseconds (Closed)
Patch Set: Change minimum DTMF event duration to be 40 milliseconds Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/pc/dtmfsender.cc
diff --git a/webrtc/pc/dtmfsender.cc b/webrtc/pc/dtmfsender.cc
index bbb100ea61789d3b295170131793af258c8ec3cb..a08a53ce0e59dbd4a2ede5c4e3574a5338d6e245 100644
--- a/webrtc/pc/dtmfsender.cc
+++ b/webrtc/pc/dtmfsender.cc
@@ -39,10 +39,10 @@ static const int kDtmfCodeTwoSecondDelay = -1;
static const int kDtmfTwoSecondInMs = 2000;
static const char kDtmfValidTones[] = ",0123456789*#ABCDabcd";
static const char kDtmfTonesTable[] = ",0123456789*#ABCD";
// The duration cannot be more than 6000ms or less than 70ms. The gap between
the sun 2017/02/16 13:55:45 Add reference to spec.
// tones must be at least 50 ms.
static const int kDtmfDefaultDurationMs = 100;
-static const int kDtmfMinDurationMs = 70;
+static const int kDtmfMinDurationMs = 40;
static const int kDtmfMaxDurationMs = 6000;
static const int kDtmfDefaultGapMs = 50;
static const int kDtmfMinGapMs = 50;
@@ -39,10 +39,10 @@ static const int kDtmfCodeTwoSecondDelay = -1;
static const char kDtmfValidTones[] = ",0123456789*#ABCDabcd";
static const char kDtmfTonesTable[] = ",0123456789*#ABCD";
-// The duration cannot be more than 6000ms or less than 70ms. The gap between
+// The duration cannot be more than 6000ms or less than 40ms. The gap between
the sun 2017/02/16 13:55:45 Add reference to spec.
// tones must be at least 50 ms.

Powered by Google App Engine
This is Rietveld 408576698